package com.ruoyi.project.business.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.business.mapper.TpParabarDetailValueMapper;
import com.ruoyi.project.business.domain.TpParabarDetailValue;
import com.ruoyi.project.business.service.ITpParabarDetailValueService;

import javax.annotation.Resource;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-28
 */
@Service
public class TpParabarDetailValueServiceImpl implements ITpParabarDetailValueService 
{
    @Resource
    private TpParabarDetailValueMapper tpParabarDetailValueMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public TpParabarDetailValue selectTpParabarDetailValueById(Long id)
    {
        return tpParabarDetailValueMapper.selectTpParabarDetailValueById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tpParabarDetailValue 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<TpParabarDetailValue> selectTpParabarDetailValueList(TpParabarDetailValue tpParabarDetailValue)
    {
        return tpParabarDetailValueMapper.selectTpParabarDetailValueList(tpParabarDetailValue);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param tpParabarDetailValue 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertTpParabarDetailValue(TpParabarDetailValue tpParabarDetailValue)
    {
        tpParabarDetailValue.setCreateTime(DateUtils.getNowDate());
        return tpParabarDetailValueMapper.insertTpParabarDetailValue(tpParabarDetailValue);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param tpParabarDetailValue 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateTpParabarDetailValue(TpParabarDetailValue tpParabarDetailValue)
    {
        tpParabarDetailValue.setUpdateTime(DateUtils.getNowDate());
        return tpParabarDetailValueMapper.updateTpParabarDetailValue(tpParabarDetailValue);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTpParabarDetailValueByIds(Long[] ids)
    {
        return tpParabarDetailValueMapper.deleteTpParabarDetailValueByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteTpParabarDetailValueById(Long id)
    {
        return tpParabarDetailValueMapper.deleteTpParabarDetailValueById(id);
    }
}
